pub enum Level {
Debug = 0,
Info = 1,
Warning = 2,
Error = 3,
Critical = 4,
}Expand description
Severity level of a log message, ordered from least to most severe.
The numeric values are stable and used for cheap comparisons and for
storing the level in an atomic (as u8 / Level::from_u8).
Variants
Debug = 0
Fine-grained detail for diagnosing problems.
Info = 1
Routine confirmation that things are working.
Warning = 2
Something unexpected, or a problem that may occur soon.
Error = 3
A failure that prevented some operation from completing.
Critical = 4
A severe failure; the program may be unable to continue.
Implementations